@@ -1,6 +1,6 @@
 /*!
 
-Use `lfs_core::read_mounts` to get information on all mounted volumes on a unix system.
+Use `lfs_core::read_mounts` to get information on all mounted volumes.
 
 ```
 // get all mount points
@@ -14,7 +14,7 @@ for mount in mounts {
 }
 ```
 
-The [lfs](https://github.com/Canop/lfs) application is a viewer for lfs-core and shows you the information you're expected to find in mounts.
+The [dysk](https://github.com/Canop/dysk) application is a viewer for lfs-core and shows you the information you're expected to find in mounts.
 
 */
 
@@ -29,8 +29,11 @@ mod linux;
 mod macos;
 mod mount;
 mod mountinfo;
+mod read_options;
 mod stats;
 mod sys;
+#[cfg(windows)]
+mod windows;
 
 pub use {
     device_id::*,
@@ -40,6 +43,7 @@ pub use {
     label::*,
     mount::*,
     mountinfo::*,
+    read_options::*,
     stats::*,
 };
 
@@ -47,3 +51,7 @@ pub use {
 pub use linux::read_mounts;
 #[cfg(target_os = "macos")]
 pub use macos::read_mounts;
+#[cfg(windows)]
+pub use windows::read_mounts;
+#[cfg(windows)]
+pub use windows::volume_serial_for_path;
